@@ -1,4 +1,4 @@
-# Copyright (C) 1998,1999,2000 by the Free Software Foundation, Inc.
+# Copyright (C) 1998,1999,2000,2001,2002 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -25,4 +25,4 @@ import time
 
 def process(mlist, msg, msgdata):
     mlist.last_post_time = time.time()
-    mlist.post_id = mlist.post_id + 1
+    mlist.post_id += 1
